@@ -185,6 +185,18 @@ pub const LIBSSH2_CHANNEL_EXTENDED_DATA_NORMAL: c_int = 0;
 pub const LIBSSH2_CHANNEL_EXTENDED_DATA_IGNORE: c_int = 1;
 pub const LIBSSH2_CHANNEL_EXTENDED_DATA_MERGE: c_int = 2;
 
+pub const LIBSSH2_SESSION_BLOCK_INBOUND: c_int = 1;
+pub const LIBSSH2_SESSION_BLOCK_OUTBOUND: c_int = 2;
+
+pub const  LIBSSH2_TRACE_TRANS : c_int = 1<<1;
+pub const  LIBSSH2_TRACE_KEX   : c_int = 1<<2;
+pub const  LIBSSH2_TRACE_AUTH  : c_int = 1<<3;
+pub const  LIBSSH2_TRACE_CONN  : c_int = 1<<4;
+pub const  LIBSSH2_TRACE_SCP   : c_int = 1<<5;
+pub const  LIBSSH2_TRACE_SFTP  : c_int = 1<<6;
+pub const  LIBSSH2_TRACE_ERROR : c_int = 1<<7;
+pub const  LIBSSH2_TRACE_PUBLICKEY : c_int = 1<<8;
+pub const  LIBSSH2_TRACE_SOCKET : c_int = 1<<9;
 pub enum LIBSSH2_SESSION {}
 pub enum LIBSSH2_AGENT {}
 pub enum LIBSSH2_CHANNEL {}
@@ -296,9 +308,9 @@ pub struct LIBSSH2_USERAUTH_KBDINT_RESPONSE {
 
 #[cfg(unix)]
 pub type libssh2_socket_t = c_int;
-#[cfg(all(windows, target_arch = "x86"))]
+#[cfg(all(windows, target_pointer_width = "32"))]
 pub type libssh2_socket_t = u32;
-#[cfg(all(windows, target_arch = "x86_64"))]
+#[cfg(all(windows, target_pointer_width = "64"))]
 pub type libssh2_socket_t = u64;
 
 extern "C" {
@@ -307,6 +319,7 @@ extern "C" {
     pub fn libssh2_exit();
     pub fn libssh2_free(sess: *mut LIBSSH2_SESSION, ptr: *mut c_void);
     pub fn libssh2_hostkey_hash(session: *mut LIBSSH2_SESSION, hash_type: c_int) -> *const c_char;
+    pub fn libssh2_trace(session: *mut LIBSSH2_SESSION, bitmask: c_int) -> c_int;
 
     // session
     pub fn libssh2_session_init_ex(
@@ -347,6 +360,7 @@ extern "C" {
         method_type: c_int,
         algs: *mut *mut *const c_char,
     ) -> c_int;
+    pub fn libssh2_session_last_errno(sess: *mut LIBSSH2_SESSION) -> c_int;
     pub fn libssh2_session_last_error(
         sess: *mut LIBSSH2_SESSION,
         msg: *mut *mut c_char,
@@ -362,6 +376,7 @@ extern "C" {
     );
     pub fn libssh2_keepalive_send(sess: *mut LIBSSH2_SESSION, seconds_to_next: *mut c_int)
         -> c_int;
+    pub fn libssh2_session_block_directions(sess: *mut LIBSSH2_SESSION) -> c_int;
 
     // agent
     pub fn libssh2_agent_init(sess: *mut LIBSSH2_SESSION) -> *mut LIBSSH2_AGENT;
@@ -486,6 +501,7 @@ extern "C" {
         channel: *mut LIBSSH2_CHANNEL,
         mode: c_int,
     ) -> c_int;
+    pub fn libssh2_channel_request_auth_agent(channel: *mut LIBSSH2_CHANNEL) -> c_int;
 
     // userauth
     pub fn libssh2_userauth_authenticated(sess: *mut LIBSSH2_SESSION) -> c_int;
@@ -720,9 +736,9 @@ fn smoke() {
 pub fn issue_14344_workaround() {}
 
 pub fn init() {
-    use std::sync::{Once, ONCE_INIT};
+    use std::sync::Once;
 
-    static INIT: Once = ONCE_INIT;
+    static INIT: Once = Once::new();
     INIT.call_once(|| unsafe {
         platform_init();
         assert_eq!(libc::atexit(shutdown), 0);
